@@ -13,13 +13,22 @@
 #include <KWindowSystem>
 
 #include <QApplication>
+#include <QDBusConnection>
+#include <QFileInfo>
 #include <QPainter>
+#include <QMainWindow>
+#include <QMenuBar>
+#include <QMdiArea>
+#include <QDockWidget>
+#include <QWindow>
 
 #if BREEZE_HAVE_QTX11EXTRAS
 #include <QX11Info>
 #endif
 
 #include <algorithm>
+#include <QDialog>
+
 
 namespace Breeze
 {
@@ -28,14 +37,37 @@ namespace Breeze
     static const qreal arrowShade = 0.15;
 
     //____________________________________________________________________
-    Helper::Helper( KSharedConfig::Ptr config ):
-        _config( std::move( config ) )
-    {}
+    Helper::Helper( KSharedConfig::Ptr config, QObject *parent ) :
+        QObject ( parent ),
+        _config( std::move( config ) ),
+        _kwinConfig( KSharedConfig::openConfig("kwinrc") ),
+        _decorationConfig( new InternalSettings() )
+    {
+        if (qApp) {
+            connect(qApp, &QApplication::paletteChanged, this, [=]() {
+                if (qApp->property("KDE_COLOR_SCHEME_PATH").isValid()) {
+                    const auto path = qApp->property("KDE_COLOR_SCHEME_PATH").toString();
+                    KConfig config(path, KConfig::SimpleConfig);
+                    KConfigGroup group( config.group("WM") );
+                    const QPalette palette( QApplication::palette() );
+                    _activeTitleBarColor = group.readEntry( "activeBackground", palette.color( QPalette::Active, QPalette::Highlight ) );
+                    _activeTitleBarTextColor = group.readEntry( "activeForeground", palette.color( QPalette::Active, QPalette::HighlightedText ) );
+                    _inactiveTitleBarColor = group.readEntry( "inactiveBackground", palette.color( QPalette::Disabled, QPalette::Highlight ) );
+                    _inactiveTitleBarTextColor = group.readEntry( "inactiveForeground", palette.color( QPalette::Disabled, QPalette::HighlightedText ) );
+                }
+            });
+        }
+    }
 
     //____________________________________________________________________
     KSharedConfig::Ptr Helper::config() const
     { return _config; }
 
+
+    //____________________________________________________________________
+    QSharedPointer<InternalSettings> Helper::decorationConfig() const
+    { return _decorationConfig; }
+
     //____________________________________________________________________
     void Helper::loadConfig()
     {
@@ -47,11 +79,18 @@ namespace Breeze
         _viewNeutralTextBrush = KStatefulBrush( KColorScheme::View, KColorScheme::NeutralText );
 
         const QPalette palette( QApplication::palette() );
-        const KConfigGroup group( _config->group( "WM" ) );
-        _activeTitleBarColor = group.readEntry( "activeBackground", palette.color( QPalette::Active, QPalette::Highlight ) );
-        _activeTitleBarTextColor = group.readEntry( "activeForeground", palette.color( QPalette::Active, QPalette::HighlightedText ) );
-        _inactiveTitleBarColor = group.readEntry( "inactiveBackground", palette.color( QPalette::Disabled, QPalette::Highlight ) );
-        _inactiveTitleBarTextColor = group.readEntry( "inactiveForeground", palette.color( QPalette::Disabled, QPalette::HighlightedText ) );
+        _config->reparseConfiguration();
+        _kwinConfig->reparseConfiguration();
+        _cachedAutoValid = false;
+        _decorationConfig->load();
+
+        KConfig config(qApp->property("KDE_COLOR_SCHEME_PATH").toString(), KConfig::SimpleConfig);
+        KConfigGroup appGroup( config.group("WM") );
+        KConfigGroup globalGroup( _config->group("WM") );
+        _activeTitleBarColor = appGroup.readEntry( "activeBackground", globalGroup.readEntry( "activeBackground", palette.color( QPalette::Active, QPalette::Highlight ) ) );
+        _activeTitleBarTextColor = appGroup.readEntry( "activeForeground", globalGroup.readEntry( "activeForeground", palette.color( QPalette::Active, QPalette::HighlightedText ) ) );
+        _inactiveTitleBarColor = appGroup.readEntry( "inactiveBackground", globalGroup.readEntry( "inactiveBackground", palette.color( QPalette::Disabled, QPalette::Highlight ) ) );
+        _inactiveTitleBarTextColor = appGroup.readEntry( "inactiveForeground", globalGroup.readEntry( "inactiveForeground", palette.color( QPalette::Disabled, QPalette::HighlightedText ) ) );
     }
 
     //____________________________________________________________________
@@ -443,7 +482,7 @@ namespace Breeze
 
             QRectF copy( strokedRect( rect ) );
 
-            const qreal radius( frameRadius( PenWidth::Frame, -1 ) );
+            const qreal radius( frameRadius( PenWidth::Frame ) );
             if( !(sides&SideTop) ) copy.adjust( 0, -radius, 0, 0 );
             if( !(sides&SideBottom) ) copy.adjust( 0, 0, 0, radius );
             if( !(sides&SideLeft) ) copy.adjust( -radius, 0, 0, 0 );
@@ -476,7 +515,8 @@ namespace Breeze
     //______________________________________________________________________________
     void Helper::renderFrame(
         QPainter* painter, const QRect& rect,
-        const QColor& color, const QColor& outline ) const
+        const QColor& color, const QColor& outline,
+        FrameHints hints ) const
     {
 
         painter->setRenderHint( QPainter::Antialiasing );
@@ -502,6 +542,19 @@ namespace Breeze
         if( color.isValid() ) painter->setBrush( color );
         else painter->setBrush( Qt::NoBrush );
 
+        if (hints & FrameHint::DoubleRing) {
+            painter->save();
+            {
+                auto rect2 = frameRect.adjusted( -2, -2, 2, 2 );
+                painter->setPen( Qt::NoPen );
+                painter->setBrush( outline );
+                painter->setOpacity( 0.4 );
+
+                painter->drawRoundedRect(rect2, radius*2, radius*2);
+            }
+            painter->restore();
+        }
+
         // render
         painter->drawRoundedRect( frameRect, radius, radius );
 
@@ -568,7 +621,7 @@ namespace Breeze
 
             painter->setRenderHint( QPainter::Antialiasing );
             QRectF frameRect( rect );
-            qreal radius( frameRadius( PenWidth::NoPen, -1 ) );
+            qreal radius( frameRadius( PenWidth::NoPen ) );
 
             // set pen
             if( outline.isValid() )
@@ -1597,4 +1650,42 @@ namespace Breeze
         }
         return pixmap;
     }
+
+    bool Helper::shouldDrawToolsArea(const QWidget* widget) const {
+        if (!widget) {
+            return false;
+        }
+        static bool isAuto = false;
+        static QString borderSize;
+        if (!_cachedAutoValid) {
+            KConfigGroup kdecorationGroup(_kwinConfig->group("org.kde.kdecoration2"));
+            isAuto = kdecorationGroup.readEntry("BorderSizeAuto", true);
+            borderSize = kdecorationGroup.readEntry("BorderSize", "Normal");
+            _cachedAutoValid = true;
+        }
+        if (isAuto) {
+            auto window = widget->window();
+            if (qobject_cast<const QDialog*>(widget)) {
+                return true;
+            }
+            if (window) {
+                auto handle = window->windowHandle();
+                if (handle) {
+                    auto toolbar = qobject_cast<const QToolBar*>(widget);
+                    if (toolbar) {
+                        if (toolbar->isFloating()) {
+                            return false;
+                        }
+                    }
+                    return true;
+                }
+            } else {
+                return false;
+            }
+        }
+        if (borderSize != "None" && borderSize != "NoSides") {
+            return false;
+        }
+        return true;
+    }
 }
