@@ -44,13 +44,19 @@ namespace Breeze
         static constexpr int Layout_DefaultSpacing = 6;
 
         // line editors
-        static constexpr int LineEdit_FrameWidth = 6;
+        struct LineEdit {
+            static constexpr int FrameWidth = 6;
+            static constexpr int Margin = 2;
+
+            static constexpr int TotalExpansion = FrameWidth + Margin;
+        };
 
         // menu items
         static constexpr int Menu_FrameWidth = 0;
-        static constexpr int MenuItem_MarginWidth = 5;
-        static constexpr int MenuItem_MarginHeight = 3;
+        static constexpr int MenuItem_MarginWidth = 10;
+        static constexpr int MenuItem_MarginHeight = 5;
         static constexpr int MenuItem_ItemSpacing = 4;
+        static constexpr int MenuItem_SeparatorPadding = 0;
         static constexpr int MenuItem_AcceleratorSpace = 16;
         static constexpr int MenuButton_IndicatorWidth = 20;
 
@@ -58,7 +64,7 @@ namespace Breeze
         static constexpr int ComboBox_FrameWidth = 6;
 
         // spinbox
-        static constexpr int SpinBox_FrameWidth = LineEdit_FrameWidth;
+        static constexpr int SpinBox_FrameWidth = LineEdit::TotalExpansion;
         static constexpr int SpinBox_ArrowButtonWidth = 20;
 
         // groupbox title margin
@@ -92,7 +98,7 @@ namespace Breeze
         static constexpr int ScrollBar_DoubleButtonHeight = 2*ScrollBar_Extend;
 
         // toolbars
-        static constexpr int ToolBar_FrameWidth = 2;
+        static constexpr int ToolBar_FrameWidth = 6;
         static constexpr int ToolBar_HandleExtent = 10;
         static constexpr int ToolBar_HandleWidth = 6;
         static constexpr int ToolBar_SeparatorWidth = 8;
