@@ -48,6 +48,7 @@ namespace Breeze
     class WidgetExplorer;
     class WindowManager;
     class BlurHelper;
+    class ToolsAreaManager;
 
     //* convenience typedef for base class
     #if !BREEZE_HAVE_KSTYLE
@@ -83,6 +84,9 @@ namespace Breeze
         //* widget unpolishing
         void unpolish( QWidget* ) override;
 
+        //* application polishing
+        void polish( QApplication* ) override;
+
         //* polish scrollarea
         void polishScrollArea( QAbstractScrollArea* );
 
@@ -230,6 +234,7 @@ namespace Breeze
         { return true; }
 
         bool drawFramePrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
+        bool drawPanelLineEditPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
         bool drawFrameLineEditPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
         bool drawFrameFocusRectPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
         bool drawFrameMenuPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
@@ -267,6 +272,7 @@ namespace Breeze
         bool drawIndicatorToolBarHandlePrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
         bool drawIndicatorToolBarSeparatorPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
         bool drawIndicatorBranchPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
+        bool drawWidgetPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
 
         //@}
 
@@ -496,6 +502,9 @@ namespace Breeze
         //* splitter Factory, to extend splitters hit area
         SplitterFactory* _splitterFactory = nullptr;
 
+        //* signal manager for the tools area
+        ToolsAreaManager* _toolsAreaManager = nullptr;
+
         //* widget explorer
         WidgetExplorer* _widgetExplorer = nullptr;
 
